#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions       : 10/3/2008
#
#package			: bubblemon
#homepage			: http://www.ne.jp/asahi/linux/timecop/
#source location	: http://www.ne.jp/asahi/linux/timecop/software/bubblemon-dockapp-1.46.tar.gz
#dependency         : 

softname='bubblemon-dockapp'
softversion='1.46'
packageversion='52.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# log
#
(

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.ne.jp/asahi/linux/timecop/software/$softname-$softversion.tar.gz

#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc 
                 |-----handy-ruler------------------------------------------------------|
bubblemon-dockapp: bubblemon-dockapp - a system CPU and memory load monitor.
bubblemon-dockapp:
bubblemon-dockapp: It displays something that looks like a vial containing water. 
bubblemon-dockapp: The water level indicates how much memory is in use. The color of 
bubblemon-dockapp: the liquid indicates how much swap space is used (watery blue means 
bubblemon-dockapp: none and angry red means all). The system CPU load is indicated by 
bubblemon-dockapp: bubbles floating up through the liquid; lots of bubbles means high 
bubblemon-dockapp: CPU load. If you have unread mail, a message in a bottle falls 
bubblemon-dockapp: into the water.
bubblemon-dockapp: 
bubblemon-dockapp:
EOF

#
# Verifie si package est present
#
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xzvf $srcpkg
cd $src	
patch -p 1 < ../bubblemon-1.46-gtk.patch

#
# "faire" le package package
#
make $numjobs DESTDIR=$dest

#
# installer le package dans son répertoire de destination
#
cp bubblemon $dest/$prefix/bin

#
# ajout des fichiers de docs, infos, ...
#
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      ChangeLog INSTALL README SUPPORTED_SYSTEMS\
      $dest/usr/doc/$softname-$softversion
    cp -a doc/COPYING doc/Xdefaults.sample $dest/usr/doc/$softname-$softversion
	
#
# Stripper les éxécutables
# (Commenter ces lignes si besoin d'infos de débuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion
cp bubblemon-1.46-gtk.patch $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "atk,expat,fontconfig,freetype,glib2,gtk+2,libpng,pango,xorg-libs,xorg-xcb,zlib" > $package.dep

#
# produire le fichier src
#
echo -e "http://users.zenwalk.org/user-accounts/bip/EXTRA/xap/bubblemon-dockapp/source/bubblemon-1.46-gtk.patch" >$softname-$softversion-noarch-$packageversion.src
echo $source >>$softname-$softversion-noarch-$packageversion.src

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
